{
  am_pm_abbreviated => [
    "\N{U+2d5c}\N{U+2d49}\N{U+2d3c}\N{U+2d30}\N{U+2d61}\N{U+2d5c}",
    "\N{U+2d5c}\N{U+2d30}\N{U+2d37}\N{U+2d33}\N{U+2d33}\N{U+2d6f}\N{U+2d30}\N{U+2d5c}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "MM-dd, E",
    MMM => "MMM",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "zgh",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+2d30}\N{U+2d62}\N{U+2d4f}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d49}",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d55}",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d61}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d49}\N{U+2d4e}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d49}\N{U+2d39}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d30}",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "\N{U+2d30}\N{U+2d62}\N{U+2d4f}\N{U+2d30}\N{U+2d59}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d49}\N{U+2d4f}\N{U+2d30}\N{U+2d59}",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d55}\N{U+2d30}\N{U+2d59}",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d61}\N{U+2d30}\N{U+2d59}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d49}\N{U+2d4e}\N{U+2d61}\N{U+2d30}\N{U+2d59}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d49}\N{U+2d39}\N{U+2d62}\N{U+2d30}\N{U+2d59}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d30}\N{U+2d4e}\N{U+2d30}\N{U+2d59}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+2d30}\N{U+2d62}\N{U+2d4f}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d49}",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d55}",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d61}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d49}\N{U+2d4e}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d49}\N{U+2d39}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d30}",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "\N{U+2d30}\N{U+2d62}\N{U+2d4f}\N{U+2d30}\N{U+2d59}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d49}\N{U+2d4f}\N{U+2d30}\N{U+2d59}",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d55}\N{U+2d30}\N{U+2d59}",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d61}\N{U+2d30}\N{U+2d59}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d49}\N{U+2d4e}\N{U+2d61}\N{U+2d30}\N{U+2d59}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d49}\N{U+2d39}\N{U+2d62}\N{U+2d30}\N{U+2d59}",
    "\N{U+2d30}\N{U+2d59}\N{U+2d30}\N{U+2d4e}\N{U+2d30}\N{U+2d59}",
  ],
  era_abbreviated => [
    "\N{U+2d37}\N{U+2d30}\N{U+2d44}",
    "\N{U+2d37}\N{U+2d3c}\N{U+2d44}",
  ],
  era_narrow => [
    "\N{U+2d37}\N{U+2d30}\N{U+2d44}",
    "\N{U+2d37}\N{U+2d3c}\N{U+2d44}",
  ],
  era_wide => [
    "\N{U+2d37}\N{U+2d30}\N{U+2d5c} \N{U+2d4f} \N{U+2d44}\N{U+2d49}\N{U+2d59}\N{U+2d30}",
    "\N{U+2d37}\N{U+2d3c}\N{U+2d3c}\N{U+2d49}\N{U+2d54} \N{U+2d4f} \N{U+2d44}\N{U+2d49}\N{U+2d59}\N{U+2d30}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Standard Moroccan Tamazight",
  month_format_abbreviated => [
    "\N{U+2d49}\N{U+2d4f}\N{U+2d4f}",
    "\N{U+2d31}\N{U+2d55}\N{U+2d30}",
    "\N{U+2d4e}\N{U+2d30}\N{U+2d55}",
    "\N{U+2d49}\N{U+2d31}\N{U+2d54}",
    "\N{U+2d4e}\N{U+2d30}\N{U+2d62}",
    "\N{U+2d62}\N{U+2d53}\N{U+2d4f}",
    "\N{U+2d62}\N{U+2d53}\N{U+2d4d}",
    "\N{U+2d56}\N{U+2d53}\N{U+2d5b}",
    "\N{U+2d5b}\N{U+2d53}\N{U+2d5c}",
    "\N{U+2d3d}\N{U+2d5c}\N{U+2d53}",
    "\N{U+2d4f}\N{U+2d53}\N{U+2d61}",
    "\N{U+2d37}\N{U+2d53}\N{U+2d4a}",
  ],
  month_format_narrow => [
    "\N{U+2d49}",
    "\N{U+2d31}",
    "\N{U+2d4e}",
    "\N{U+2d49}",
    "\N{U+2d4e}",
    "\N{U+2d62}",
    "\N{U+2d62}",
    "\N{U+2d56}",
    "\N{U+2d5b}",
    "\N{U+2d3d}",
    "\N{U+2d4f}",
    "\N{U+2d37}",
  ],
  month_format_wide => [
    "\N{U+2d49}\N{U+2d4f}\N{U+2d4f}\N{U+2d30}\N{U+2d62}\N{U+2d54}",
    "\N{U+2d31}\N{U+2d55}\N{U+2d30}\N{U+2d62}\N{U+2d55}",
    "\N{U+2d4e}\N{U+2d30}\N{U+2d55}\N{U+2d5a}",
    "\N{U+2d49}\N{U+2d31}\N{U+2d54}\N{U+2d49}\N{U+2d54}",
    "\N{U+2d4e}\N{U+2d30}\N{U+2d62}\N{U+2d62}\N{U+2d53}",
    "\N{U+2d62}\N{U+2d53}\N{U+2d4f}\N{U+2d62}\N{U+2d53}",
    "\N{U+2d62}\N{U+2d53}\N{U+2d4d}\N{U+2d62}\N{U+2d53}\N{U+2d63}",
    "\N{U+2d56}\N{U+2d53}\N{U+2d5b}\N{U+2d5c}",
    "\N{U+2d5b}\N{U+2d53}\N{U+2d5c}\N{U+2d30}\N{U+2d4f}\N{U+2d31}\N{U+2d49}\N{U+2d54}",
    "\N{U+2d3d}\N{U+2d5c}\N{U+2d53}\N{U+2d31}\N{U+2d54}",
    "\N{U+2d4f}\N{U+2d53}\N{U+2d61}\N{U+2d30}\N{U+2d4f}\N{U+2d31}\N{U+2d49}\N{U+2d54}",
    "\N{U+2d37}\N{U+2d53}\N{U+2d4a}\N{U+2d30}\N{U+2d4f}\N{U+2d31}\N{U+2d49}\N{U+2d54}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+2d49}\N{U+2d4f}\N{U+2d4f}",
    "\N{U+2d31}\N{U+2d55}\N{U+2d30}",
    "\N{U+2d4e}\N{U+2d30}\N{U+2d55}",
    "\N{U+2d49}\N{U+2d31}\N{U+2d54}",
    "\N{U+2d4e}\N{U+2d30}\N{U+2d62}",
    "\N{U+2d62}\N{U+2d53}\N{U+2d4f}",
    "\N{U+2d62}\N{U+2d53}\N{U+2d4d}",
    "\N{U+2d56}\N{U+2d53}\N{U+2d5b}",
    "\N{U+2d5b}\N{U+2d53}\N{U+2d5c}",
    "\N{U+2d3d}\N{U+2d5c}\N{U+2d53}",
    "\N{U+2d4f}\N{U+2d53}\N{U+2d61}",
    "\N{U+2d37}\N{U+2d53}\N{U+2d4a}",
  ],
  month_stand_alone_narrow => [
    "\N{U+2d49}",
    "\N{U+2d31}",
    "\N{U+2d4e}",
    "\N{U+2d49}",
    "\N{U+2d4e}",
    "\N{U+2d62}",
    "\N{U+2d62}",
    "\N{U+2d56}",
    "\N{U+2d5b}",
    "\N{U+2d3d}",
    "\N{U+2d4f}",
    "\N{U+2d37}",
  ],
  month_stand_alone_wide => [
    "\N{U+2d49}\N{U+2d4f}\N{U+2d4f}\N{U+2d30}\N{U+2d62}\N{U+2d54}",
    "\N{U+2d31}\N{U+2d55}\N{U+2d30}\N{U+2d62}\N{U+2d55}",
    "\N{U+2d4e}\N{U+2d30}\N{U+2d55}\N{U+2d5a}",
    "\N{U+2d49}\N{U+2d31}\N{U+2d54}\N{U+2d49}\N{U+2d54}",
    "\N{U+2d4e}\N{U+2d30}\N{U+2d62}\N{U+2d62}\N{U+2d53}",
    "\N{U+2d62}\N{U+2d53}\N{U+2d4f}\N{U+2d62}\N{U+2d53}",
    "\N{U+2d62}\N{U+2d53}\N{U+2d4d}\N{U+2d62}\N{U+2d53}\N{U+2d63}",
    "\N{U+2d56}\N{U+2d53}\N{U+2d5b}\N{U+2d5c}",
    "\N{U+2d5b}\N{U+2d53}\N{U+2d5c}\N{U+2d30}\N{U+2d4f}\N{U+2d31}\N{U+2d49}\N{U+2d54}",
    "\N{U+2d3d}\N{U+2d5c}\N{U+2d53}\N{U+2d31}\N{U+2d54}",
    "\N{U+2d4f}\N{U+2d53}\N{U+2d61}\N{U+2d30}\N{U+2d4f}\N{U+2d31}\N{U+2d49}\N{U+2d54}",
    "\N{U+2d37}\N{U+2d53}\N{U+2d4a}\N{U+2d30}\N{U+2d4f}\N{U+2d31}\N{U+2d49}\N{U+2d54}",
  ],
  name => "Standard Moroccan Tamazight",
  native_language => "\N{U+2d5c}\N{U+2d30}\N{U+2d4e}\N{U+2d30}\N{U+2d63}\N{U+2d49}\N{U+2d56}\N{U+2d5c}",
  native_name => "\N{U+2d5c}\N{U+2d30}\N{U+2d4e}\N{U+2d30}\N{U+2d63}\N{U+2d49}\N{U+2d56}\N{U+2d5c}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+2d30}\N{U+2d3d} 1",
    "\N{U+2d30}\N{U+2d3d} 2",
    "\N{U+2d30}\N{U+2d3d} 3",
    "\N{U+2d30}\N{U+2d3d} 4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+2d30}\N{U+2d3d}\N{U+2d55}\N{U+2d30}\N{U+2d39}\N{U+2d62}\N{U+2d53}\N{U+2d54} 1",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d55}\N{U+2d30}\N{U+2d39}\N{U+2d62}\N{U+2d53}\N{U+2d54} 2",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d55}\N{U+2d30}\N{U+2d39}\N{U+2d62}\N{U+2d53}\N{U+2d54} 3",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d55}\N{U+2d30}\N{U+2d39}\N{U+2d62}\N{U+2d53}\N{U+2d54} 4",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+2d30}\N{U+2d3d} 1",
    "\N{U+2d30}\N{U+2d3d} 2",
    "\N{U+2d30}\N{U+2d3d} 3",
    "\N{U+2d30}\N{U+2d3d} 4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+2d30}\N{U+2d3d}\N{U+2d55}\N{U+2d30}\N{U+2d39}\N{U+2d62}\N{U+2d53}\N{U+2d54} 1",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d55}\N{U+2d30}\N{U+2d39}\N{U+2d62}\N{U+2d53}\N{U+2d54} 2",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d55}\N{U+2d30}\N{U+2d39}\N{U+2d62}\N{U+2d53}\N{U+2d54} 3",
    "\N{U+2d30}\N{U+2d3d}\N{U+2d55}\N{U+2d30}\N{U+2d39}\N{U+2d62}\N{U+2d53}\N{U+2d54} 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 40,
}
